@@ -50,8 +50,8 @@ sub finalize_body {
     if ( blessed($body) && $body->can('read') or ref($body) eq 'GLOB' ) {
         my $got;
         do {
-            read $body, my ($buffer), $CHUNKSIZE;
-            last unless $self->write( $c, $buffer );
+            $got = read $body, my ($buffer), $CHUNKSIZE;
+            $got = 0 unless $self->write( $c, $buffer );
         } while $got > 0;
 
         close $body;
